@@ -1,11 +1,11 @@
-from typing import Any, Callable, MutableMapping, Tuple
+from typing import Any, Callable, MutableMapping, Tuple, Union
 
 from blacksmith import HTTPRequest
 from blacksmith import HTTPResponse as BMResponse
 
-from whitesmith import HTTPResponse
+from whitesmith import HTTPCollectionResponse, HTTPResponse
 
-Handler = Callable[[HTTPRequest], HTTPResponse[Any]]
+Handler = Callable[[HTTPRequest], Union[HTTPResponse[Any], HTTPCollectionResponse[Any]]]
 
 
 class Router:
@@ -25,7 +25,6 @@ class Router:
             )
 
     def register(self, route: str) -> Callable[[Handler], Handler]:
-
         meth, url = route.split(maxsplit=2)
 
         def wrapper(fn: Handler) -> Handler:
